@@ -3,6 +3,7 @@
 """
 import logging
 import os
+import copy
 import random
 from pathlib import Path
 from typing import Tuple, Union
@@ -139,9 +140,9 @@ def set_mat_props(
     if bsdf_node is None:
         log.warning(f'No BSDF node in {mat.name}')
         return
-    bsdf_node.inputs['Roughness'].default_value += prop_tuple[0]
-    bsdf_node.inputs['Metallic'].default_value += prop_tuple[1]
-    bsdf_node.inputs['Specular'].default_value += prop_tuple[2]
+    bsdf_node.inputs['Roughness'].default_value = copy.copy(prop_tuple[0])
+    bsdf_node.inputs['Metallic'].default_value = copy.copy(prop_tuple[1])
+    bsdf_node.inputs['Specular'].default_value = copy.copy(prop_tuple[2])
 
 
 @gin.configurable
@@ -172,7 +173,7 @@ def jitter(
 
 @gin.configurable
 def random_texture_mat(
-    texture_dir: Union[Path, str] = 'lib/textures/random',
+    texture_dir: Union[Path, str] = 'lib/textures/random_512p',
     relative_to_assets_dir: bool = True,
 ) -> bpy.types.Material:
     """ Generate a random material from a directory of random texture images.
@@ -229,7 +230,7 @@ def make_mat_from_texture(
     tex_node.image = bpy.data.images[texture_path.name]
     tex_node.image.colorspace_settings.name = 'Filmic Log'
     mat.node_tree.links.new(tex_node.outputs[0], bsdf_node.inputs[0])
-    mat.node_tree.links.new(coord_node.outputs[0], tex_node.inputs[0])
+    mat.node_tree.links.new(coord_node.outputs[2], tex_node.inputs[0])
     mat.node_tree.links.new(out_node.inputs[0], bsdf_node.outputs[0])
     tex_node.image.reload()
     return mat
